/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2015 Bitquant Research Laboratories (Asia) Limited

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#include <ql/experimental/cryptocurrency/cryptofuture.hpp>
#include <ql/exercise.hpp>


namespace QuantLib {
    CryptoCurrencyFuture::CryptoCurrencyFuture(const Date& maturityDate,
                                               const boost::shared_ptr<CryptoPayoff>& payoff) :
        OneAssetOption(payoff,
                       boost::shared_ptr<Exercise>(new 
                                  EuropeanExercise(maturityDate))) {};

    CryptoPayoff::CryptoPayoff(Real multiplier) :
        multiplier_(multiplier) {};

    Real CryptoPayoff::payoffFiat(Real price) const {
        return (*this)(price);
    }

    Real CryptoPayoff::payoffCrypto(Real price) const {
        return (*this)(price) / price;
    }

    CryptoPayoffInverse::CryptoPayoffInverse(Real multiplier) : CryptoPayoff(multiplier) {};
    Real CryptoPayoffInverse::operator()(Real price) const {
        return multiplier_;
    }

    CryptoPayoffQuanto::CryptoPayoffQuanto(Real multiplier) : CryptoPayoff(multiplier) {};
    Real CryptoPayoffQuanto::operator()(Real price) const {
        return multiplier_ * price * price;
    }

}

