/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2015 Bitquant Research Laboratories (Asia) Limited

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

/*! \file cryptofuture.hpp
  \brief classes for cryptofuture
*/

#ifndef quantlib_cryptofuture_hpp
#define quantlib_cryptofuture_hpp

#include <ql/instruments/forward.hpp>
#include <ql/time/daycounters/continuoustime.hpp>
#include <ql/instruments/oneassetoption.hpp>

namespace QuantLib {
    class CryptoPayoff;
    //! CryptoCurrencyFuture
    class CryptoCurrencyFuture : public OneAssetOption {
    public:
        CryptoCurrencyFuture(const Date& maturityDate,
                             const boost::shared_ptr<CryptoPayoff>& payoff);
    };
    
    //! CryptoPayoff
    class CryptoPayoff : public Payoff {
    public:
        CryptoPayoff(Real multiplier);
        virtual Real payoffFiat(Real price) const;
        virtual Real payoffCrypto(Real price) const;
    protected:
        Real multiplier_;
    };

    //! CryptoPayoffQuanto
    class CryptoPayoffQuanto : public CryptoPayoff {
    public:
        CryptoPayoffQuanto(Real multiplier=100.0);
        std::string name() const { return "CryptoPayoffQuantoType";}
        std::string description() const { return "";}
        virtual Real operator()(Real price) const;
    };

    //! CryptoPayoffInverse
    class CryptoPayoffInverse : public CryptoPayoff {
    public:
        CryptoPayoffInverse(Real multiplier=0.00001);
        std::string name() const { return "CryptoPayoffInverseType";}
        std::string description() const { return "";}
        virtual Real operator()(Real price) const;
    };
}

#endif

